/*
 * Licensed Materials - Property of IBM
 * 
 * 5724-I66
 * 
 * (C) Copyright IBM Corporation 2005, 2006. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights: Use, duplication or
 * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 * 
 * DISCLAIMER: The following [enclosed] code is sample code created by IBM
 * Corporation. This sample code is not part of any standard IBM product and is
 * provided to you solely for the purpose of assisting you in the development of
 * your applications. The code is provided 'AS IS', without warranty of any kind
 * IBM shall not be liable for any damages arising out of your use of sample
 * code, even if they have been advised of the possibility of such damages.
 */
package bean;

import module.application.loan.main.process.interface_.MainProcessInterface;

public class IndexBean {

	private Invoker util = null;

	public IndexBean() {
		super();
		//Get the utility class for calling stand-alone references and creating SDO objects
		util = new Invoker();
	}

	public String submitLoanApplication(double loanAmount, String taxPayerId, String name,
			String email) {

		/*
		 * Default output message
		 */
		String operationOutput = "Sorry, We cannot process your application at this time due to internal error.";

		try {

			/*
			 * Name of Loan Application's stand-alone reference
			 * 
             *  (You can view the details of this stand-alone reference by opening LoanApplicationModule's assembly
             *   diagram, selecting the "Stand-alone References" component, expanding the "References" tree on the
             *   Details tab of the Properties view, and selecting References->mainProcessInterfacePartner.)
             *
			 */
			String standAloneReferenceName = "mainProcessInterfacePartner";

			
			/*
			 * Retrieve java interface representation of the Stand-alone reference
			 * 
			 * (The mainProcessInterfacePartner stand-alone reference was declared as a java reference in 
			 *  the assembly diagram mentionned above. The Interface field on the
			 *  Details tab for References->mainProcessInterfacePartner shows the 
			 *  module.application.loan.com.mybank.loan.main.process.interface_.MainProcessInterface
			 *  java interface class that was created by the tooling.
			 *  Call the applyOnline() operation using this java interface class. )
			 * 
			 */
			MainProcessInterface javaInterfaceImpl = null;

			javaInterfaceImpl = (MainProcessInterface) util
					.getService(standAloneReferenceName);

			/*
			 * Create input SDO objects (java representation of WID business objects)
			 */
			commonj.sdo.DataObject input_ApplicationBO = null;
			commonj.sdo.DataObject input_ApplicantBO = null;

			
			input_ApplicantBO = util.createBO("ApplicantBO",
					"http://LoanApplicationModule");
			input_ApplicationBO = util.createBO("ApplicationBO",
					"http://LoanApplicationModule");

			/*
			 * Assign values to Applicant Business Object. All mandatory attributes
			 * must be assigned . ContactBO is a superset of Applicant BO which
			 * has attributes name and email
			 */
			input_ApplicantBO.setString("taxPayerId", taxPayerId);
			input_ApplicantBO.setString("name", name);
			input_ApplicantBO.setString("email", email);

			/*
			 * Assign values to Applicant Business Object. The application object
			 * contains the applicant object
			 */
			input_ApplicationBO.setDataObject("applicant", input_ApplicantBO);
			input_ApplicationBO.setDouble("loanamount", loanAmount);

			/*
			 * Call the applyOnline operation using the java interface class
			 */
			String result = javaInterfaceImpl.applyOnline(input_ApplicationBO);

			/*
			 * Assign the string result to operationOutput
			 */
			operationOutput = result;

		} catch (Exception e) {
			e.printStackTrace();
		}

		return operationOutput;
	}

}
